#
# spec file for package k9s
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           k9s
Version:        0.27.4
Release:        1.2
Summary:        Curses based terminal UI for Kubernetes clusters
License:        Apache-2.0
URL:            https://github.com/derailed/k9s
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.19
ExcludeArch:    s390
ExcludeArch:    %{ix86}

%description
K9s provides a curses based terminal UI to interact with your Kubernetes
clusters. The aim of this project is to make it easier to navigate, observe
and manage your applications in the wild. K9s continually watches Kubernetes
for changes and offers subsequent commands to interact with observed
Kubernetes resources.

%prep
%setup -qa1

%build
make GO_FLAGS="-mod=vendor -buildmode=pie" GIT_REV="" VERSION="%{version}" build

%install
# Install the binary.
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 execs/k9s %{buildroot}%{_bindir}/k9s

%files
%license LICENSE
%doc README.md
%{_bindir}/k9s

%changelog
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.27.4:
  * Rel v0.27.4 (#2075)
  * feat: allow customization of log indicator toggles closes #2024
    (#2041)
  * Create narsingh.yml (#2067)
  * fix: (views) use saved context view when switching (#2045)
  * Unify all go version to 1.20 (#2069)
  * Bump github.com/rs/zerolog from 1.29.0 to 1.29.1 (#2060)
  * Bump helm.sh/helm/v3 from 3.11.1 to 3.11.3 (#2059)
  * Fix for missing Job annotations created from CronJob (#2073)
  * Roles are rendered using same colorer function from skin
    (#2027)
  * Bump github.com/fatih/color from 1.14.1 to 1.15.0 (#2023)
  * Updated monokai skin with help styles, and more monokai
    appropriate colors (#2030)
  * Bump alpine from 3.17.2 to 3.17.3 (#2040)
  * Bump github.com/docker/docker (#2044)
  * Bump actions/checkout from 3.3.0 to 3.5.2 (#2058)
  * Bump golang from 1.20.2-alpine3.16 to 1.20.3-alpine3.16 (#2049)
  * Update setup-go action, with caching (#2054)
  * Convert command to lowercase in the command palette (#1432)
  * Allowing a few hard coded colors to be configurable (#1405)
  * fix: multiple matches in a single line. (#1876)
  * generated binary zip for windows (#1972)
  * feat: add support for renaming contexts. (#2006)
  * Fix accessing nil map (#1996)
  * Sort by view default only if sort not currently set (#1962)
  * fix: fix outdated stern links (#1990)
  * Update k8s matrix (#1979)
  * Bump github.com/containerd/containerd from 1.6.15 to 1.6.18
    (#1981)
  * Bump github.com/derailed/popeye from 0.11.0 to 0.11.1 (#1986)
  * adding instruction to install in FreeBSD via pkg (#1991)
  * Bump k8s.io/metrics from 0.26.1 to 0.26.2 (#1998)
  * added full logs viewing (#2002)
  * Bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#1993)
  * Bump k8s.io/client-go from 0.26.1 to 0.26.2 (#1999)
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 (#2000)
  * Bump golang from 1.20.0-alpine3.16 to 1.20.2-alpine3.16 (#2008)
  * Fix #2007: Remove debug command (#2011)
  * Bump alpine from 3.17.1 to 3.17.2 (#1974)
  * Bump golang.org/x/text from 0.6.0 to 0.7.0 (#1976)
  * Bump github.com/derailed/popeye from 0.10.1 to 0.11.0 (#1975)
  * Add missing help menu to one_dark skin (#1973)
* Sun Feb 12 2023 kastl@b1-systems.de
- Update to version 0.27.3 (bsc#1208087, CVE-2023-25165):
  * Release v0.27.3 (#1970)
  * Add sort by pod count on node view (#1961)
  * fix: Show meaningful error message when kubectl exec fails (#1966)
  * set default sinceSeconds to 300 (#1965)
  * Match ${XXX} environment variables (#1896)
  * Bump github.com/cenkalti/backoff/v4 from 4.1.3 to 4.2.0 (#1957)
  * Bump k8s.io/klog/v2 from 2.80.1 to 2.90.0 (#1958)
  * Bump golang from 1.19.5-alpine3.16 to 1.20.0-alpine3.16 (#1956)
  * Bump github.com/fatih/color from 1.13.0 to 1.14.1 (#1959)
  * Added Nightfox theme (#1960)
  * fix: Add missing help menu to gruvbox-dark skin (#1969)
  * Bump helm.sh/helm/v3 from 3.11.0 to 3.11.1 (#1963)
  * update docs
  * fix: acessing clusters with private dns (#1903)
  * Bump actions/setup-go from 3.3.1 to 3.5.0 (#1899)
  * Bump helm.sh/helm/v3 from 3.10.1 to 3.11.0 (#1928)
  * Bump github.com/rs/zerolog from 1.28.0 to 1.29.0 (#1942)
- BuildRequire go1.19
* Wed Feb  1 2023 kastl@b1-systems.de
- Update to version 0.27.2:
  * fix brew installer
  * bring out the duds
* Tue Jan 31 2023 kastl@b1-systems.de
- Update to version 0.27.1:
  * release v0.27.1 (#1945)
  Resolved Issues
  * [Issue #1943](https://github.com/derailed/k9s/issues/1943) k9s display is broken after switching to v0.27.0
  * [Issue #1935](https://github.com/derailed/k9s/issues/1935) Active namespace is dropped after accessing forbidden resources
  * [Issue #1913](https://github.com/derailed/k9s/issues/1913) Exit edit mode deadlock
  * [Issue #1895](https://github.com/derailed/k9s/issues/1895) AWS workspace. K9s fails on startup with unknown userid error
  * [Issue #1842](https://github.com/derailed/k9s/issues/1842) Strange one - brew installed k9s
* Fri Jan 27 2023 kastl@b1-systems.de
- Update to version 0.27.0:
  * K9s/rel v0.27.0 (#1932)
  * Bump alpine from 3.16.2 to 3.17.1 (#1907)
  * Replace x86_64 to amd64 build (#1910)
  * Bump actions/checkout from 3.1.0 to 3.3.0 (#1908)
  * Bump golang from 1.19.2-alpine3.16 to 1.19.5-alpine3.16 (#1915)
  * Use default terminal colors for better readability (#1290) (#1837)
  * Add labels configuration to Shell node pod (#1847)
  * Set build date on macos (#1849)
  * Update ScanSA calls to account for blank service accounts (#1871)
  * Add k8s client compatibility matrix (#1872)
  * bugfix for port forward custom containers not showing #1844 (#1877)
  * feat: add noLatestRevCheck config option (#1874)
  * Add policy view to serviceAccounts (#1840)
  * Add VIM-like quit force option. (#1859)
  * Fix order of arguments for `CanI` function call (#1866)
  * Update README.md (#1696)
  * Bump all references of github.com/cenkalti/backoff to v4 (#1821)
  * Plugin support for carvel kapp CR (#1830)
  * flux.yml plugin now displays stderr messages (#1829)
  * Bump actions/setup-go from 3.1.0 to 3.3.1 (#1817)
* Tue Oct 18 2022 kastl@b1-systems.de
- Update to version 0.26.7:
  * K9s/rel v0.26.7 (#1816)
  * Bump k8s.io/klog/v2 from 2.70.1 to 2.80.1 (#1779)
  * Bump github.com/rs/zerolog from 1.27.0 to 1.28.0 (#1780)
  * Bump golang from 1.19.1-alpine3.16 to 1.19.2-alpine3.16 (#1796)
  * Bump actions/checkout from 2 to 3.1.0 (#1795)
  * Bump github.com/mattn/go-runewidth from 0.0.13 to 0.0.14 (#1813)
  * Bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#1814)
  * Allow multiple port forwards for a single Pod (#1804)
  * Bump k8s.io/kubectl from 0.25.1 to 0.25.3 (#1809)
  * Bump golang.org/x/text from 0.3.7 to 0.4.0 (#1812)
  * Bump github.com/fsnotify/fsnotify from 1.5.4 to 1.6.0 (#1810)
  * Bump k8s.io/cli-runtime from 0.25.1 to 0.25.3 (#1811)
  * use go install (#1797)
  * Bump k8s.io/client-go from 0.25.1 to 0.25.3 (#1806)
  * Bump k8s.io/metrics from 0.25.1 to 0.25.3 (#1807)
  * Bump k8s.io/apimachinery from 0.25.1 to 0.25.3 (#1808)
  * Update CronJob version to v1 (#1793)
* Tue Sep 27 2022 kastl@b1-systems.de
- Update to version 0.26.6:
  * K9s/rel v0.26.6 (#1784)
  * fix #1773
  * Fix directory path when viewing ScreenDump (#1777)
  * docs: update homebrew installation note (#1772)
  * Log toggles: add a space after "On" in logs view (#1775)
  * Add a closing tag when showing timestamp in log view (#1776)
* Sun Sep 25 2022 kastl@b1-systems.de
- Update to version 0.26.5:
  * release v0.26.5 (#1771)
* Sun Sep 25 2022 kastl@b1-systems.de
- Update to version 0.26.4:
  * clean up test
  * K9s/rel v0.26.4 (#1767)
  * Replace clipboard package (#868) (#1721)
  * List all helm releases (#1755)
  * Fix GracePeriodSeconds (#1739)
  * Plugin for opening a root shell to k3d containter (#1709)
  * Fix  Get CustomResourceDefinition(#1711) (#1722)
  * Fix flux plugin to properly handle trace (#1753)
  * README : correct (auto-)port-forwards annotations (#1744)
  * Fix typo in cronjob (#1759)
  * Bump golang from 1.19.0-alpine3.16 to 1.19.1-alpine3.16 (#1754)
  * fix redundant type conversion code (#1725)
  * update tag
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.3:
  * hotfix: windoze
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.2:
  * K9s/rel v0.26.2 (#1691)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.1:
  * K9s/rel v0.26.1 (#1685)
  * Fix persistentvolumes not showing terminating status (#1682)
  * Show UsedBy for PriorityClasses (#1666)
  * feat: allow disable CTRL-C behavior (#1672)
  * Fix PF delete with no container (#1668)
* Mon Jul 18 2022 kastl@b1-systems.de
- Update to version 0.26.0:
  * cleaning up deprecation
  * K9s/rel v0.26.0 (#1660)
  * Fix PF and RS colors (#1656)
  * Fix #1636: can't switch context with --kubeconfig flag (#1638)
* Fri Jul  1 2022 kastl@b1-systems.de
- Update to version 0.25.21:
  * K9s rel v0.25.21 (#1635)
  * Fix delete dialog dropdown styling (#1632)
  * Fix TestToAge (#1627)
  * Fix reference to base image in Dockerfile (#1629)
  * [FIX] chg makefile version (#1624)
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.25.20:
  * K9s release v0.25.20 (#1621)
  * Issue #1620 popeye view shows duplicate pdb
  * Issue #1616 Age in nodes view are n/a
* Tue Jun 28 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.18, as upstream says in go.mod
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.25.19:
  * update deps
  * K9s release v0.25.19 (#1610)
  * Fix typo in FastForwards annotation name (#1600)
  * Capitalise true/false when checking suspension (#1601)
  * Allow all deletion propagation policies (#1553)
  * fix: correct typo (#1566)
  * Add Helm values support (#1518)
  * Add locking favorite namespaces (#1449) (#1519)
  * plugin to allow default chart values retrieval (#1539)
  * fix view details secret fullscreen padding to 0 (#1493)
  * Fix the flux plugin to use the context of the currently running instance (#1366)
  * Fix Typo (#1422)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.18:
  * Issue #1402 Sort functionality does not work properly on v0.25.16. With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.17:
  * Issue #1402 Sort functionality does not work properly on v0.25.16
  * Issue #1401 Nothin selected when last item deleted
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.16:
  * Issue #1398 Pod logs containing brackets not in k9s logs output
  * Issue #1397 Regression: k9s no longer starts in current context namespace since v0.25.12
  * Issue #1358 Namespaces list is empty
  * Issue #956 Feature request : Default column sort (by resource view)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.15:
  * Issue #1384 Leaving Logs View Causes Crash: "panic: send on closed channel" - with feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.14:
  * Issue #1384 Leaving Logs View Causes Crash: "panic: send on closed channel"
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.13:
  * Issue #1382 Watcher failed for screendumps
  * Issue #1381 --request-timeout affects logs streaming
  * Issue #1380 :pulse returning error: expecting a TableRow but got *v1.Table
  * Issue #1376 Events are not sorted correctly by dates - with feelings...
  * Issue #1291 K9s do not show any error when is unable to get logs, just do not show anything.
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.12:
  * Issue #1378 Regression: Namespace filters are no longer applied on startup
  * Issue #1376 Events not sorted correctly by dates
  * Issue #1375 Unable to show port forwards
  * Issue #1374 --all-namespaces does not work v0.25.10
  * Issue #1373 change namespace not possible
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.10:
  * update rev
  * must get moore sleep!
  * k9s: release v0.25.9 (#1364)
  * Add customizable dump directory property (#1321)
  * Add flux trace shortcut to flux plugin (#1356)
  * Add rose-pine skin (#1363)
* Sun Dec  5 2021 dmueller@suse.com
- Update to version 0.25.8:
  * release v0.25.8 (#1354)
  * add logFile flag to change the default log file path (#1336)
  * Support colors on Windows (#1312)
* Sun Nov 28 2021 Lingchao Xin <douglarek@gmail.com>
- Update to version 0.25.7:
  - Bug fixes
  * Issue #1341 Colored container logs are not displayed correctly
  See more: https://github.com/derailed/k9s/releases/tag/v0.25.7
* Fri Nov 26 2021 douglarek@gmail.com
- Update to version 0.25.6:
  - Bug fixes
  * Log level not showing in k9s
  * Namespace filter automatically applied after viewing a deployment
  See more: https://github.com/derailed/k9s/releases/tag/v0.25.6
* Fri Aug 13 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.15:
  - Breaking changes
  * K9s home directory is now configurable via XDG
  - Bug fixes
  * Popeye run instructions
  * K9s does not remember last view when switching contexts
  * Cannot list roles
* Fri Jul 23 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.14:
  * Bug fixes
- Drop Makefile.patch as new build variables were added to the Makefile
* Tue May 25 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.10:
  * Bug fixes
- Update Makefile.patch to version 0.24.10
* Fri May  7 2021 dmueller@suse.com
- Update to version 0.24.9:
  * fix shell issue + bugz
  * Dynamically load style for help from skin (#1113)
  * Solarized light skin (#1114)
  * Update docs
  * add rel notes
  * when k9s --insecure-skip-tls-verify is set, kubectl would set the same (#1101)
  * Add Nord skin (#1103)
  * wins palette
  * Spelling (#1089)
  * Allow to override build date with SOURCE_DATE_EPOCH (#1099)
  * Create axual.yml (#934)
  * Add gruvbox skins (#1088)
* Sat Apr 10 2021 dmueller@suse.com
- Update to version 0.24.7:
  * cleaning up
  * bump rev
  * maintenance #1067 #1061 #1060
  * rev up
  * merge prs + dep updates
  * ISSUE-957 - Add a simple pause button to stop auto-refresh on ConfigMap and Secrets (#1062)
  * bugs #1063 #1061 #1059 #177
  * Add release tag (#1058)
  * fix #1056 #1024
  * fix po feature col + lockouts?
* Mon Mar 29 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.6:
  * rev up
  * merge prs + dep updates
  * ISSUE-957 - Add a simple pause button to stop auto-refresh on ConfigMap and Secrets (#1062)
  * bugs #1063 #1061 #1059 #177
  * Add release tag (#1058)
  * fix #1056 #1024
  * fix po feature col + lockouts?
  * fix #1024
  * update deps and image
- Rename Makefile.diff to Makefile.patch
* Fri Jan  8 2021 rbrown@suse.com
- Update to version 0.24.2:
  * add rel notes
  * cleanup + rel notes
  * fix typo and clean up prs
  * Add OneDark color theme.
  * handling non json lines as raw with red color
  * Disable filtering on the Help screen
  * Handle Empty Port List in PortForward View
* Sat Dec  5 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.24.1 (bsc#1179668):
  * Add Monokai skin
  * Print resources in pod view
  * Slow down reconnection rate on auth failures
  * Logs page for any pod/container shows Waiting for logs...
  * Support sort by pending status
  * Wrong highlight position when filtering logs
  * Disable read only config via command line flag
  * Ability to call out a separate program to parse/filter logs
  * Full screen mode or remove borders in YAML view for easy copy/paste
  * Refresh for describe & yaml view
  * View logs quickly scrolls through entire logs when initially loading
  * Support an inverse operator on filtered search
  * Log file spammed despite K9s not running
  * Events view
  * Dozens of bug fixes
- Makefile.diff: refresh
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.21.7:
  - see https://github.com/derailed/k9s/releases
* Mon Mar 30 2020 Michal Vyskocil <mvyskocil@opensuse.org>
- Update to version 0.18.1
  - Many bug fixes
  - Many new features (auto suggestions, revisited logs, k9 plugins)
  - see https://github.com/derailed/k9s/releases/
* Tue Feb 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.15.2
  - Many bug fixes
  - Many new features
* Mon Jan 20 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.13.0
  - Add Dracula Skin
  - Add XRay Vision
  - Bug fixes
- Update vendor.tar.gz
* Mon Jan 13 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.12.0
  - Performance fixes
  - Searchable Logs
  - APIServer Dud
  - FullScreen Logs
* Tue Jan  7 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.11.2
  - Many bug fixes
  - Prelimary support for Helm 3 charts
  - Major rework of the core
  - Custom skins per cluster
* Thu Nov  7 2019 kukuk@suse.de
- Initial version
